#!/usr/bin/env python3
# -*- coding: utf-8 -*-

blacklists = {
  "propornot": [
    "4thmedia.org",
    "nsnbc.me",
    "presstv.com",
    "theunhivedmind.com",
    "sana.sy",
    "activistpost.com",
    "americasfreedomfighters.com",
    "beforeitsnews.com",
    "corbettreport.com",
    "drudgereport.com",
    "endingthefed.com",
    "globalresearch.ca",
    "hangthebankers.com",
    "infowars.com",
    "naturalnews.com",
    "paulcraigroberts.org",
    "ronpaulinstitute.org",
    "southfront.org",
    "theantimedia.org",
    "trueactivist.com",
    "veteranstoday.com",
    "washingtonsblog.com",
    "yournewswire.com",
    "zerohedge.com",
    "4threvolutionarywar.wordpress.com",
    "abeldanger.net",
    "ahtribune.com",
    "allnewspipeline.com",
    "americanlookout.com",
    "amren.com",
    "amtvmedia.com",
    "ancient-code.com",
    "anonews.co",
    "anonhq.com",
    "antiwar.com",
    "asia-pacificresearch.com",
    "assassinationscience.com",
    "baltimoregazette.com",
    "barenakedislam.com",
    "bignuggetnews.com",
    "blackagendareport.com",
    "blacklistednews.com",
    "christianfightback.com",
    "collective-evolution.com",
    "conservativedailypost.com",
    "consortiumnews.com",
    "cosmicscientist.com",
    "countercurrents.org",
    "counterinformation.wordpress.com",
    "dailyoccupation.com",
    "dailystormer.com",
    "darkmoon.me",
    "darkpolitricks.com",
    "davidstockmanscontracorner.com",
    "dcclothesline.com",
    "dcleaks.com",
    "defenddemocracy.press",
    "dennismichaellynch.com",
    "disclose.tv",
    "disclosuremedia.net",
    "educate-yourself.org",
    "educateinspirechange.org",
    "endoftheamericandream.com",
    "endtime.com",
    "eutopia.buzz",
    "ewao.com",
    "eyeopening.info",
    "fellowshipoftheminds.com",
    "filmsforaction.org",
    "floridasunpost.com",
    "foreignpolicyjournal.com",
    "fourwinds10.net",
    "freedomoutpost.com",
    "gaia.com",
    "galacticconnection.com",
    "gatesofvienna.net",
    "geopolmonitor.com",
    "godlikeproductions.com",
    "govtslaves.info",
    "greanvillepost.com",
    "guccifer2.wordpress.com",
    "healthnutnews.com",
    "henrymakow.com",
    "heresyblog.net",
    "humansarefree.com",
    "ihavethetruth.com",
    "ihavethetruth.com",
    "in5d.com",
    "informationclearinghouse.info",
    "intellihub.com",
    "intrepidreport.com",
    "investmentresearchdynamics.com",
    "investmentwatchblog.com",
    "jackpineradicals.com",
    "jamesrgrangerjr.com",
    "jewsnews.co.il",
    "journal-neo.org",
    "katehon.com",
    "katehon.org",
    "kingworldnews.com",
    "lewrockwell.com",
    "libertyblitzkrieg.com",
    "libertywritersnews.com",
    "makeamericagreattoday.com",
    "mintpressnews.com",
    "moonofalabama.org",
    "nakedcapitalism.com",
    "naturalblaze.com",
    "newcoldwar.org",
    "newstarget.com",
    "newswithviews.com",
    "nowtheendbegins.com",
    "off-guardian.org",
    "oftwominds.com",
    "opednews.com",
    "orientalreview.org",
    "patriotrising.com",
    "platosguns.com",
    "pravda.ru",
    "pravdareport.com",
    "prepperwebsite.com",
    "prisonplanet.com",
    "rbth.com",
    "readynutrition.com",
    "redflagnews.com",
    "regated.com",
    "rense.com",
    "righton.com",
    "rinf.com",
    "rt.com",
    "rumormillnews.com",
    "ruptly.tv",
    "russia-insider.com",
    "sentinelblog.com",
    "sgtreport.com",
    "shiftfrequency.com",
    "shtfplan.com",
    "silentmajoritypatriots.com",
    "silverdoctors.com",
    "sott.net",
    "sputniknews.com",
    "stormcloudsgathering.com",
    "strategic-culture.org",
    "superstation95.com",
    "survivopedia.com",
    "the-newspapers.com",
    "thecommonsenseshow.com",
    "thedailybell.com",
    "thedailysheeple.com",
    "theduran.com",
    "theearthchild.co.za",
    "theeconomiccollapseblog.com",
    "theeventchronicle.com",
    "thefederalistpapers.org",
    "thefreethoughtproject.com",
    "themindunleashed.org",
    "thenewsdoctors.com",
    "therebel.media",
    "therussophile.org",
    "thesaker.is",
    "thesleuthjournal.com",
    "thetruenews.info",
    "thetruthseeker.co.uk",
    "thirdworldtraveler.com",
    "toprightnews.com",
    "trunews.com",
    "truth-out.org",
    "truthandaction.org",
    "truthdig.com",
    "truthfeed.com",
    "truthkings.com",
    "ufoholic.com",
    "undergroundworldnews.com",
    "unz.com",
    "usanewshome.com",
    "usapoliticsnow.com",
    "usasupreme.com",
    "usdcrisis.com",
    "usslibertyveterans.org",
    "vdare.com",
    "veteransnewsnow.com",
    "vigilantcitizen.com",
    "viralliberty.com",
    "voltairenet.org",
    "wakeupthesheep.com",
    "wakingtimes.com",
    "wearechange.org",
    "weshapelife.org",
    "whatdoesitmean.com",
    "whatreallyhappened.com",
    "wikileaks.com",
    "wikileaks.org",
    "wikispooks.com",
    "worldnewspolitics.com",
    "worldpoliticsus.com",
    "www.fort-russ.com",
    "oilgeopolitics.net",
    "gangstergovernment.com",
    "memoryholeblog.com",
    "eutimes.net",
    "intersectionproject.eu"
  ],
  "fortliberty.org": [
    "21stcenturywire.com",
    "800whistleblower.com",
    "activistpost.com",
    "alternet.org",
    "americannews.com",
    "antiwar.com",
    "beforeitsnews.com",
    "bigpzone.com",
    "chronicle.su",
    "consciouslifenews.com",
    "conspiracywire.com",
    "countdowntozerotime.com",
    "counterpsyops.com",
    "dailybuzzlive.com",
    "dailycurrant.com",
    "dcclothesline.com",
    "disclose.tv",
    "duffelblog.com",
    "duhprogressive.com",
    "elitereaders.com",
    "empirenews.net",
    "english.ruvr.ru",
    "eutimes.net",
    "federalistpress.com",
    "freepatriot.org",
    "fromthetrenchesworldreport.com",
    "geoengineeringwatch.org",
    "globalresearch.ca",
    "gonzoglobe.com",
    "govtslaves.info",
    "guardianlv.com",
    "gulagbound.com",
    "hangthebankers.com",
    "healthimpactnews.com",
    "humansarefree.com",
    "huzlers.com",
    "infowars.com",
    "intellihub.com",
    "lewrockwell.com",
    "libertynews.com",
    "livefreelivenatural.com",
    "nationalreport.net",
    "naturalcuresnotmedicine.com",
    "naturalnews.com",
    "newswire-24.com",
    "nodisinfo.com",
    "notallowedto.com",
    "now8news.com",
    "nowtheendbegins.com",
    "pakalertpress.com",
    "politicalblindspot.com",
    "presstv.ir",
    "prisonplanet.com",
    "randpaulreview.com",
    "rawforbeauty.com",
    "realfarmacy.com",
    "redflagnews.com",
    "responsibletechnology.org",
    "rt.com",
    "secretsofthefed.com",
    "southweb.org",
    "thecommonsenseshow.com",
    "thecontroversialfiles.net",
    "thedailysheeple.com",
    "thefreethoughtproject",
    "thelastgreatstand.com",
    "thenewamerican.com",
    "theracketreport.com",
    "therightplanet.com",
    "therundownlive.com",
    "theuspatriot.com",
    "topinfopost.com",
    "truthandaction.org",
    "truthbroadcastnetwork.com",
    "turnerradionetwork.com",
    "undergroundhealth.com",
    "usahitman.com",
    "veteranstoday.com",
    "westernjournalism.com",
    "whydontyoutrythis.com",
    "worldnewsdailyreport.com",
    "worldtruth.tv",
    "yournewswire.com"
  ],
  "zimdar": [
    "enduringvision.com",
    "70news.wordpress.com",
    "abcnews.com.co",
    "politicalo.com",
    "americannews.com",
    "indecisionforever.com",
    "realnewsrightnow.com",
    "infowars.com",
    "rilenews.com",
    "civictribune.com",
    "mediamass.net",
    "megynkelly.us",
    "msnbc.com.co",
    "msnbc.website",
    "nationalreport.net",
    "creambmp.com",
    "news-hound.com",
    "newsbiscuit.com",
    "dcgazette.com",
    "politicops.com",
    "newsmutiny.com",
    "drudgereport.com.co",
    "empirenews.net"
  ]
}